summaryrefslogtreecommitdiff
path: root/gtk2_ardour/sfdb_ui.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/sfdb_ui.cc')
-rw-r--r--gtk2_ardour/sfdb_ui.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/gtk2_ardour/sfdb_ui.cc b/gtk2_ardour/sfdb_ui.cc
index 3383cf3ff9..8916a53971 100644
--- a/gtk2_ardour/sfdb_ui.cc
+++ b/gtk2_ardour/sfdb_ui.cc
@@ -1339,8 +1339,9 @@ SoundFileOmega::reset_options ()
src_combo.set_sensitive (false);
}
- /* We must copy MIDI files or those from Freesound */
- bool const must_copy = have_a_midi_file || notebook.get_current_page() == 2;
+ /* We must copy MIDI files or those from Freesound
+ * or any file if we are under nsm control */
+ bool const must_copy = _session->get_nsm_state() || have_a_midi_file || notebook.get_current_page() == 2;
if (Config->get_only_copy_imported_files()) {